.BG
.FN mixed.text
.FN mixed.mtext
.TL 
Mixed-font versions of text and mtext
.DN
Plot text with mixed fonts, heights, sizes, using `postscript()' or 
screen graphics device drivers.
.CS
mixed.text(x, y, texts, esc="~", cex=par("cex"), 
  font=par("font"), srt=0, slope, noprint=F,fill.zero=T,adj=0)

mixed.mtext(side = 3, line = 0, outer. = F, at, texts, 
  esc = "~", cex = par("cex"), font = par("font"), 
  srt = 0, slope, noprint = F, fill.zero=T,adj=0)
.AG x
Numeric vector, x-position of start of string (but see `adj' argument below)
.AG y
Numeric vector, y-position of start of string
.AG side
side (1,2,3,4 for bottom, left, top, or right).
.AG line
line (measured out from the plot in units of standard-sized
character heights).
The default values of graphical parameter `mar' allow
characters to be placed at values of `line' less than or equal to
4 on the bottom, 3 on left and top, and 1 on the right.
.AG outer
logical flag, should plotting be done in outer margin?
.AG at
optional vector of positions at which `text' is to be
plotted.  If `side' is 1 or 3, `at' will represent x-coordinates.
If `side' is 2 or 4, `at' will represent y-coordinates.
`at' can be used for constructing specialized
axis labels, etc.
.AG texts
Character string.  (For `mixed.text()', a vector of character strings is
accepted.)  The string may be regarded as broken into segments
separated by the escape character.  The character immediately following
the escape character defines the meaning of the segment.  For most 
escapes, lower case applies only to the immediately following text string
while upper case resets the default for the rest of the text.

The following escapes are available:
 . = plot the following text (may be omitted before initial text
segment if plotted with default values), f/F = set font of
next/default; c/C = set character size (cex) relative to original cex,
next/default; h/H = set height relative to baseline, next/default; u/U
= raise ("up") text next/default relative to previous height; 
d/D = drop text next/default relative to previous height; a/A
like u/U but half space units; v/V like d/D but half space units; s/S =
forward space half/full space before next text; b/B = back space
half/full space before next text, e/E = insert a string beginning/ending with
the escape character.

All escapes except ".", "E", and "e" take an
optional numeric argument (treated as a multiplier for spacing
commands), 1 by default.  (Therefore, ~H0 returns to baseline height.)
Spacing is in em units (width of letter
`"m"').  Note that spacing commands are useful for kerning (adding or
subtracting space where different fonts meet up), for backspacing (e.g.
putting a subscript beneath a superscript), for centering text, and for
adjusting spacing when character sizes differ from those in the font
file, e.g.  when using the ISO Latin preamble.
.AG esc
Escape character separating segments: a one-character string that
should not appear in any of the text segments or be the same as any of
the codes given above (but see escape sequences "e/E" above).  Another
good choice is the backquote (but we can't get it to print in a help
file!).  Note that the "\\" character is represented by "\\\\" in S
strings.
.AG cex
Character expansion parameter for the whole string.
.AG font
Default font for starting out the string.
.AG srt
String rotation angle.  The handling of `srt' is different in `mixed.mtext'
from `mtext', in that by default text on the left and right margins is
oriented to run vertically.
.AG slope
Alternative method of expressing string rotation, as slope of the
baseline of the text in user coordinates (useful for labeling a slanted
line).
.AG noprint
Logical: if `noprint=T', nothing will be plotted.  Used to determine
length of plotted string for centering purposes (see adj argument).
.AG fill.zero
Logical: if `T', any ASCII character whose width is not given in the font
metric file will be assumed to be the same width as the letter `"A"' in
that font.  Useful when using extended character sets (e.g. with
`postscript(preamble=ps.preamble.ISO.LATIN)' ) which are not in the
standard metric files; some trial-and-error horizontal adjustment
may be needed with these characters.
.AG adj
Adjustment argument, any numeric value: 
`adj=0' (the default) defines (x,y) position as starting point (left end) of
text, `adj=1' adjusts to right end of text, `adj=0.5' to the middle.  
Any non-zero value requires an extra pass through the string to
calculate its length and will be slower.  The handling of the
`adj' argument is slightly different in `mixed.mtext()' than in `mtext()'. 
.RT
Length of plotted string in em units (width of letter `"m"'), used when 
calculating offset for text which is not left-adjusted. No value is
returned when `mixed.text()' is invoked to plot more than one string in
a single call.
.SE 
The coded string is plotted as text on the postscript plot.
Note that some useful characters (some math signs, accented letters,
and superscripts) are available using ISO-Latin extended fonts:
see help for `ps.show.fonts()', and for `ps.setfont.latin1' in S-PLUS.

This code is designed primarily for postscript plots.  By default,
spacing for a screen device will be an approximation to the values
required to give the desired appearance when the plot is printed using 
the `"print"' button on the window.  Spacings that may have a better
appearance on screen can be obtained by the option setting command
`"options(mixed.text.screen=T)"'.  However, due to the limitations and 
varied characteristics of screen graphics devices, the results will not
be consistent.

.EX
> postscript()
> plot(1:10,1:10,type="n",xlab="",ylab=""); abline(-1,1.3)
> mixed.text(3,3.4,
"Plot of: ~F4~f13~.b~u~c.7~.az~.PQ~d~c.7~f27~.1~b.3~u~c.7~f13~.ao~c2~f7~.+I",cex=2,slope=1.3)
> mixed.mtext(1,1.5,at=5,texts="This is the ~f4~.X~A~f13~s~.G~f1~.+1~H0~. axis",
	adj=.5)
.SA
`ps.show.fonts', `fontdemo', `mixed.text.vector', `ps.setfont.latin1'
.KW aplot
.WR
